# frozen_string_literal: true

# Displaying news for visitors
class NewsController < ApplicationController
  before_action :set_category, only: :category
  before_action :set_entity, only: :show

  # get /news
  def index
    post_type = PostType.find_by(slug: 'news')
    @collection = post_type.posts.page_for_visitors(current_page)
    respond_to do |format|
      format.html
      format.json { render('posts/index') }
    end
  end

  # get /news/:category_slug
  def category
    @collection = Post.in_category_branch(@category).for_language(current_language).page_for_visitors(current_page)
    respond_to do |format|
      format.html
      format.json { render('posts/index') }
    end
  end

  # get /news/:post_id-:post_slug
  def show
    @entity.increment :view_count
    @entity.increment :rating, 0.0025
    @entity.save
  end

  # get /news/:category_slug/:slug
  def show_in_category
    post_type = PostType.find_by(slug: 'news')
    @entity = post_type.posts.list_for_visitors.find_by(slug: params[:slug])
    if @entity.nil?
      handle_http_404('Cannot find news')
    else
      @entity.increment :view_count
      @entity.increment :rating, 0.0025
      @entity.save

      render :show
    end
  end

  # get /news/tagged/:tag_name
  def tagged
    post_type = PostType.find_by(slug: 'news')
    @collection = post_type.posts.tagged(params[:tag_name]).page_for_visitors(current_page)
  end

  private

  def set_category
    type = PostType.find_by(slug: 'news')
    @category = type.post_categories.find_by(long_slug: params[:category_slug])
    handle_http_404('Cannot find post category (news)') if @category.nil?
  end

  def set_entity
    @entity = Post.list_for_visitors.find_by(id: params[:post_id])
    handle_http_404('Cannot find news') if @entity.nil?
  end
end
